@@ -6,7 +6,8 @@ from django.utils.translation import ugettext_lazy
 from django.utils.six import with_metaclass
 
 label_re = re.compile(r'(?i)^[a-z0-9][a-z0-9-]*[a-z0-9]$')
-validate_label = RegexValidator(label_re, ugettext_lazy("Enter a valid instance label consisting of letters, numbers, or hyphens."), 'invalid')
+validate_label = RegexValidator(
+    label_re, ugettext_lazy("Enter a valid instance label consisting of letters, numbers, or hyphens."), 'invalid')
 
 try:
     from south.modelsinspector import add_introspection_rules
@@ -14,6 +15,7 @@ try:
 except ImportError:
     pass
 
+
 class DNSLabelField(with_metaclass(models.SubfieldBase, models.CharField)):
     description = "A DNS label"
 
@@ -29,4 +31,3 @@ class DNSLabelField(with_metaclass(models.SubfieldBase, models.CharField)):
         # Want immediate validation on any instance creation
         validate_label(value)
         return value.lower()
-
