@@ -4,13 +4,13 @@ from django.views.generic import ListView
 
 from instances.models import Instance
 
-urlpatterns = patterns('',
+urlpatterns = patterns(
+    '',
     (r'^$', ListView.as_view(
-        queryset = Instance.objects.all(),
-        context_object_name = 'instances',
-        template_name = 'instances/index.html',
+        queryset=Instance.objects.all(),
+        context_object_name='instances',
+        template_name='instances/index.html',
     )),
 )
 
 urlpatterns += staticfiles_urlpatterns()
-
